@@ -309,6 +309,9 @@ class SetupDs(object):
 
             val = input('\nEnter the instance name [{}]: '.format(slapd['instance_name'])).rstrip()
             if val != "":
+                if len(val) > 80:
+                    print("Server identifier should not be longer than 80 symbols")
+                    continue
                 if not all(ord(c) < 128 for c in val):
                     print("Server identifier can not contain non ascii characters")
                     continue
@@ -537,7 +540,7 @@ class SetupDs(object):
         return True
 
     def _prepare_ds(self, general, slapd, backends):
-
+        self.log.info("Validate installation settings ...")
         assert_c(general['defaults'] is not None, "Configuration defaults in section [general] not found")
         self.log.debug("PASSED: using config settings %s" % general['defaults'])
         # Validate our arguments.
@@ -601,7 +604,7 @@ class SetupDs(object):
 
         # Right now, the way that rootpw works on ns-slapd works, it force hashes the pw
         # see https://fedorahosted.org/389/ticket/48859
-        if not re.match('^\{[A-Z0-9]+\}.*$', slapd['root_password']):
+        if not re.match('^([A-Z0-9]+).*$', slapd['root_password']):
             # We need to hash it. Call pwdhash-bin.
             # slapd['root_password'] = password_hash(slapd['root_password'], prefix=slapd['prefix'])
             pass
@@ -650,9 +653,9 @@ class SetupDs(object):
         Actually does the setup. this is what you want to call as an api.
         """
 
-        self.log.debug("START: Starting installation...")
+        self.log.debug("START: Starting installation ...")
         if not self.verbose:
-            self.log.info("Starting installation...")
+            self.log.info("Starting installation ...")
 
         # Check we have privs to run
         self.log.debug("READY: Preparing installation for %s...", slapd['instance_name'])
@@ -678,9 +681,9 @@ class SetupDs(object):
 
             # Call the child api to do anything it needs.
             self._install(extra)
-        self.log.debug("FINISH: Completed installation for %s", slapd['instance_name'])
+        self.log.debug("FINISH: Completed installation for instance: slapd-%s", slapd['instance_name'])
         if not self.verbose:
-            self.log.info("Completed installation for %s", slapd['instance_name'])
+            self.log.info("Completed installation for instance: slapd-%s", slapd['instance_name'])
 
         return True
 
@@ -729,6 +732,7 @@ class SetupDs(object):
                 dse += line.replace('%', '{', 1).replace('%', '}', 1)
 
         with open(os.path.join(slapd['config_dir'], 'dse.ldif'), 'w') as file_dse:
+            ldapi_path = os.path.join(slapd['local_state_dir'], "run/slapd-%s.socket" % slapd['instance_name'])
             dse_fmt = dse.format(
                 schema_dir=slapd['schema_dir'],
                 lock_dir=slapd['lock_dir'],
@@ -745,15 +749,19 @@ class SetupDs(object):
                 rootdn=slapd['root_dn'],
                 instance_name=slapd['instance_name'],
                 ds_passwd=self._secure_password,  # We set our own password here, so we can connect and mod.
-                # This is because we never know the users input root password as they can validily give
+                # This is because we never know the users input root password as they can validly give
                 # us a *hashed* input.
                 ds_suffix=ds_suffix,
                 config_dir=slapd['config_dir'],
                 db_dir=slapd['db_dir'],
-                db_home_dir=slapd['db_home_dir']
+                db_home_dir=slapd['db_home_dir'],
+                ldapi_enabled="on",
+                ldapi=ldapi_path,
+                ldapi_autobind="on",
             )
             file_dse.write(dse_fmt)
 
+        self.log.info("Create file system structures ...")
         # Create all the needed paths
         # we should only need to make bak_dir, cert_dir, config_dir, db_dir, ldif_dir, lock_dir, log_dir, run_dir?
         for path in ('backup_dir', 'cert_dir', 'db_dir', 'ldif_dir', 'lock_dir', 'log_dir', 'run_dir'):
@@ -786,14 +794,14 @@ class SetupDs(object):
         # Copy in the collation
         srcfile = os.path.join(slapd['sysconf_dir'], 'dirsrv/config/slapd-collations.conf')
         dstfile = os.path.join(slapd['config_dir'], 'slapd-collations.conf')
-        shutil.copy2(srcfile, dstfile)
+        shutil.copy(srcfile, dstfile)
         os.chown(dstfile, slapd['user_uid'], slapd['group_gid'])
         os.chmod(dstfile, 0o440)
 
         # Copy in the certmap configuration
         srcfile = os.path.join(slapd['sysconf_dir'], 'dirsrv/config/certmap.conf')
         dstfile = os.path.join(slapd['config_dir'], 'certmap.conf')
-        shutil.copy2(srcfile, dstfile)
+        shutil.copy(srcfile, dstfile)
         os.chown(dstfile, slapd['user_uid'], slapd['group_gid'])
         os.chmod(dstfile, 0o440)
 
@@ -840,7 +848,7 @@ class SetupDs(object):
         # it's the only stable and guaranteed way to connect to the instance
         # at this point.
         #
-        # Alternately, we could use ldapi instead, which would prevent the need
+        # Use ldapi which would prevent the need
         # to configure a temp root pw in the setup phase.
         args = {
             SER_HOST: "localhost",
@@ -848,7 +856,10 @@ class SetupDs(object):
             SER_SERVERID_PROP: slapd['instance_name'],
             SER_ROOT_DN: slapd['root_dn'],
             SER_ROOT_PW: self._raw_secure_password,
-            SER_DEPLOYED_DIR: slapd['prefix']
+            SER_DEPLOYED_DIR: slapd['prefix'],
+            SER_LDAPI_ENABLED: 'on',
+            SER_LDAPI_SOCKET: ldapi_path,
+            SER_LDAPI_AUTOBIND: 'on'
         }
 
         ds_instance.allocate(args)
@@ -861,6 +872,7 @@ class SetupDs(object):
             tlsdb.reinit()
 
         if slapd['self_sign_cert']:
+            self.log.info("Create self-signed certificate database ...")
             etc_dirsrv_path = os.path.join(slapd['sysconf_dir'], 'dirsrv/')
             ssca_path = os.path.join(etc_dirsrv_path, 'ssca/')
             ssca = NssSsl(dbpath=ssca_path)
@@ -878,7 +890,7 @@ class SetupDs(object):
                         tlsdb_inst = NssSsl(dbpath=os.path.join(etc_dirsrv_path, dir))
                         tlsdb_inst.import_rsa_crt(ca)
 
-            csr = tlsdb.create_rsa_key_and_csr()
+            csr = tlsdb.create_rsa_key_and_csr(alt_names=[general['full_machine_name']])
             (ca, crt) = ssca.rsa_ca_sign_csr(csr)
             tlsdb.import_rsa_crt(ca, crt)
             if general['selinux']:
@@ -887,6 +899,7 @@ class SetupDs(object):
 
         # Do selinux fixups
         if general['selinux']:
+            self.log.info("Perform SELinux labeling ...")
             selinux_paths = ('backup_dir', 'cert_dir', 'config_dir', 'db_dir',
                              'ldif_dir', 'lock_dir', 'log_dir',
                              'run_dir', 'schema_dir', 'tmp_dir')
@@ -920,7 +933,7 @@ class SetupDs(object):
             ds_instance.config.set('nsslapd-security', 'on')
 
         # Before we create any backends, create any extra default indexes that may be
-        # dynamicly provisioned, rather than from template-dse.ldif. Looking at you
+        # dynamically provisioned, rather than from template-dse.ldif. Looking at you
         # entryUUID (requires rust enabled).
         #
         # Indexes defaults to default_index_dn
@@ -935,6 +948,7 @@ class SetupDs(object):
         # Create the backends as listed
         # Load example data if needed.
         for backend in backends:
+            self.log.info(f"Create database backend: {backend['nsslapd-suffix']} ...")
             is_sample_entries_in_props = "sample_entries" in backend
             create_suffix_entry_in_props = backend.pop('create_suffix_entry', False)
             ds_instance.backends.create(properties=backend)
@@ -965,14 +979,6 @@ class SetupDs(object):
                     # Unsupported rdn
                     raise ValueError("Suffix RDN '{}' in '{}' is not supported.  Supported RDN's are: 'c', 'cn', 'dc', 'o', and 'ou'".format(suffix_rdn_attr, backend['nsslapd-suffix']))
 
-        # Initialise ldapi socket information. IPA expects this ....
-        ldapi_path = os.path.join(slapd['local_state_dir'], "run/slapd-%s.socket" % slapd['instance_name'])
-        ds_instance.config.set('nsslapd-ldapifilepath', ldapi_path)
-        ds_instance.config.set('nsslapd-ldapilisten', 'on')
-        ds_instance.config.set('nsslapd-ldapiautobind', 'on')
-        ds_instance.config.set('nsslapd-ldapimaprootdn', slapd['root_dn'])
-
-
         # Create all required sasl maps: if we have a single backend ...
         # our default maps are really really bad, and we should feel bad.
         # they basically only work with a single backend, and they'll break
@@ -997,6 +1003,7 @@ class SetupDs(object):
         else:
             self.log.debug("Skipping default SASL maps - no backend found!")
 
+        self.log.info("Perform post-installation tasks ...")
         # Change the root password finally
         ds_instance.config.set('nsslapd-rootpw', slapd['root_password'])
 
@@ -1011,3 +1018,5 @@ class SetupDs(object):
         else:
             # Just stop the instance now.
             ds_instance.stop()
+
+        self.log.debug(" 🎉 Instance setup complete")
